@@ -60,8 +60,7 @@ class _MediaJSONEncoder(json.JSONEncoder):
             for k, v in vars(obj).items():
                 if isinstance(v, datetime):
                     v = v.strftime("%Y-%m-%dT%H:%M:%SZ")
-                attributes.update({k: v})
-
+                attributes[k] = v
             return {
                 "__type__": "__media__",
                 "attributes": attributes,
