@@ -9,10 +9,13 @@ from operator import attrgetter
 import pycountry
 import requests
 
+from .classes.app import App
 from .classes.channel import Channel
 from .classes.channelepg import ChannelEPG
 from .classes.channellist import ChannelList
 from .classes.device import Device
+from .classes.favourite import Favourite
+from .classes.favouritelist import FavouriteList
 from .classes.media import Media
 from .classes.programme import Programme
 from .classes.recordings import Recordings
@@ -27,6 +30,8 @@ from .const import (
     KNOWN_COUNTRIES,
     PVR,
     REST_CHANNEL_LIST,
+    REST_FAVOURITES,
+    REST_PATH_APPS,
     REST_PATH_DEVICEINFO,
     REST_PATH_SYSTEMINFO,
     REST_RECORDING_DETAILS,
@@ -76,9 +81,12 @@ class SkyQRemote:
         self._lastPvrId = None
         self._currentApp = APP_EPG
         self._channels = []
+        self._apps = {}
         self._error = False
         self._deviceAccess = deviceAccess(self._host)
         self._epgCacheLen = epgCacheLen
+        self._channellist = None
+        self._favouritelist = None
 
         deviceInfo = self.getDeviceInformation()
         if not deviceInfo:
@@ -110,9 +118,7 @@ class SkyQRemote:
         if self._soapControlURL is None:
             return SKY_STATE_OFF
 
-        response = self._deviceAccess.callSkySOAPService(
-            self._soapControlURL, UPNP_GET_TRANSPORT_INFO
-        )
+        response = self._deviceAccess.callSkySOAPService(self._soapControlURL, UPNP_GET_TRANSPORT_INFO)
         if response is not None:
             state = response[CURRENT_TRANSPORT_STATE]
             if state in [SKY_STATE_NOMEDIA, SKY_STATE_STOPPED]:
@@ -130,13 +136,11 @@ class SkyQRemote:
             if apps is None:
                 return self._currentApp
 
-            self._currentApp = next(
-                a for a in apps["apps"] if a["status"] == APP_STATUS_VISIBLE
-            )["appId"]
+            self._currentApp = next(a for a in apps["apps"] if a["status"] == APP_STATUS_VISIBLE)["appId"]
 
-            return self._currentApp
+            return App(self._currentApp, self._get_app_title(self._currentApp))
         except Exception:
-            return self._currentApp
+            return App(self._currentApp, self._get_app_title(self._currentApp))
 
     def getCurrentMedia(self):
         """Get the currently playing media on the SkyQ box."""
@@ -147,26 +151,27 @@ class SkyQRemote:
         pvrId = None
         live = False
 
-        response = self._deviceAccess.callSkySOAPService(
-            self._soapControlURL, UPNP_GET_MEDIA_INFO
-        )
-        if response is not None:
-            currentURI = response[CURRENT_URI]
-            if currentURI is not None:
-                if XSI in currentURI:
-                    sid = self._test_channel or int(currentURI[6:], 16)
-                    live = True
-                    channelNode = self._getChannelNode(sid)
-                    if channelNode:
-                        channel = channelNode["channel"]
-                        channelno = channelNode["channelno"]
-                        imageUrl = self._remoteCountry.buildChannelImageUrl(
-                            sid, channel
-                        )
-                elif PVR in currentURI:
-                    # Recorded content
-                    pvrId = "P" + currentURI[11:]
-                    live = False
+        response = self._deviceAccess.callSkySOAPService(self._soapControlURL, UPNP_GET_MEDIA_INFO)
+        if response is None:
+            return None
+
+        currentURI = response[CURRENT_URI]
+        if currentURI is None:
+            return None
+
+        if XSI in currentURI:
+            sid = self._test_channel or int(currentURI[6:], 16)
+            live = True
+            channelNode = self._getChannelNode(sid)
+            if channelNode:
+                channel = channelNode["channel"]
+                channelno = channelNode["channelno"]
+                imageUrl = self._remoteCountry.buildChannelImageUrl(sid, channel)
+        elif PVR in currentURI:
+            # Recorded content
+            pvrId = "P" + currentURI[11:]
+            live = False
+
         return Media(channel, channelno, imageUrl, sid, pvrId, live)
 
     def getEpgData(self, sid, epgDate, days=2):
@@ -197,19 +202,13 @@ class SkyQRemote:
                 else:
                     break
 
-        self._channel = ChannelEPG(
-            sid, channelNo, channelName, channelImageUrl, sorted(programmes)
-        )
+        self._channel = ChannelEPG(sid, channelNo, channelName, channelImageUrl, sorted(programmes))
         self._epgCache[sid] = {
             "epg": epg,
             "channel": self._channel,
             "updatetime": datetime.utcnow(),
         }
-        self._epgCache = OrderedDict(
-            sorted(
-                self._epgCache.items(), key=lambda x: x[1]["updatetime"], reverse=True
-            )
-        )
+        self._epgCache = OrderedDict(sorted(self._epgCache.items(), key=lambda x: x[1]["updatetime"], reverse=True))
         while len(self._epgCache) > self._epgCacheLen:
             self._epgCache.popitem(last=True)
 
@@ -218,6 +217,7 @@ class SkyQRemote:
     def getProgrammeFromEpg(self, sid, epgDate, queryDate):
         """Get programme from EPG for specfied time and channel."""
         sidint = 0
+        print(sid)
         try:
             sidint = int(sid)
         except ValueError:
@@ -231,10 +231,7 @@ class SkyQRemote:
             self._error = False
 
         programmeEpg = f"{str(sidint)} {epgDate.strftime('%Y%m%d')}"
-        if (
-            self._lastProgrammeEpg == programmeEpg
-            and queryDate < self._programme.endtime
-        ):
+        if self._lastProgrammeEpg == programmeEpg and queryDate < self._programme.endtime:
             return self._programme
 
         epgData = self.getEpgData(sidint, epgDate)
@@ -245,16 +242,12 @@ class SkyQRemote:
                 _LOGGER.info(
                     f"I0020 - Programme data not found for host: {self._host}/{self._overrideCountry} sid: {sid} : {epgDate}"
                 )
-                return EPG_ERROR_NO_DATA
-        else:
-            self._error = False
+            return EPG_ERROR_NO_DATA
+
+        self._error = False
 
         try:
-            programme = next(
-                p
-                for p in epgData.programmes
-                if p.starttime <= queryDate and p.endtime >= queryDate
-            )
+            programme = next(p for p in epgData.programmes if p.starttime <= queryDate and p.endtime >= queryDate)
 
             self._programme = programme
             self._lastProgrammeEpg = programmeEpg
@@ -298,9 +291,7 @@ class SkyQRemote:
             return self._recordedProgramme
         self._lastPvrId = pvrId
 
-        resp = self._deviceAccess.http_json(
-            self._jsonport, REST_RECORDING_DETAILS.format(pvrId)
-        )
+        resp = self._deviceAccess.http_json(self._jsonport, REST_RECORDING_DETAILS.format(pvrId))
         if "details" not in resp:
             _LOGGER.info(f"I0030 - Recording data not found for {pvrId}")
             return None
@@ -364,15 +355,11 @@ class SkyQRemote:
             channelsid = c["sid"]
             channelImageUrl = None  # Not available yet
             sf = c["sf"]
-            channel = Channel(
-                channelno, channelname, channelsid, channelImageUrl, sf=sf
-            )
+            channel = Channel(channelno, channelname, channelsid, channelImageUrl, sf=sf)
             channelitems.add(channel)
 
         channelnosorted = sorted(channelitems, key=attrgetter("channelnoint"))
-        self._channellist = ChannelList(
-            sorted(channelnosorted, key=attrgetter("channeltype"), reverse=True)
-        )
+        self._channellist = ChannelList(sorted(channelnosorted, key=attrgetter("channeltype"), reverse=True))
 
         return self._channellist
 
@@ -389,13 +376,37 @@ class SkyQRemote:
         channelno = channel["c"]
         channelname = channel["t"]
         channelsid = channel["sid"]
-        channelImageUrl = self._remoteCountry.buildChannelImageUrl(
-            channelsid, channelname
-        )
+        channelImageUrl = self._remoteCountry.buildChannelImageUrl(channelsid, channelname)
         sf = channel["sf"]
-        return Channel(
-            channelno, channelname, channelsid, channelImageUrl, sf=sf
-        )
+        return Channel(channelno, channelname, channelsid, channelImageUrl, sf=sf)
+
+    def getFavouriteList(self):
+        """Retrieve the list of favourites."""
+        favourites = self._deviceAccess.http_json(self._jsonport, REST_FAVOURITES)
+        if not favourites or "favourites" not in favourites:
+            return []
+
+        if not self._channellist:
+            self.getChannelList()
+
+        favitems = set()
+
+        for f in favourites["favourites"]:
+            favlcn = f["lcn"]
+            favsid = f["sid"]
+            channelno = None
+            channelname = None
+            channel = next(c for c in self._channellist.channels if c.channelsid == f["sid"])
+            if channel:
+                channelno = channel.channelno
+                channelname = channel.channelname
+            favourite = Favourite(favlcn, channelno, channelname, favsid)
+            favitems.add(favourite)
+
+        favouritesorted = sorted(favitems, key=attrgetter("lcn"))
+        self._favouritelist = FavouriteList(favouritesorted)
+
+        return self._favouritelist
 
     def press(self, sequence):
         """Issue the specified sequence of commands to SkyQ box."""
@@ -404,20 +415,14 @@ class SkyQRemote:
                 if item.casefold() not in self.commands:
                     _LOGGER.error(f"E0020 - Invalid command: {self._host} : {item}")
                     break
-                self._deviceAccess.sendCommand(
-                    self._port, self.commands[item.casefold()]
-                )
+                self._deviceAccess.sendCommand(self._port, self.commands[item.casefold()])
                 time.sleep(0.5)
         elif sequence not in self.commands:
             _LOGGER.error(f"E0030 - Invalid command: {self._host} : {sequence}")
         else:
-            self._deviceAccess.sendCommand(
-                self._port, self.commands[sequence.casefold()]
-            )
+            self._deviceAccess.sendCommand(self._port, self.commands[sequence.casefold()])
 
-    def setOverrides(
-        self, overrideCountry=None, test_channel=None, jsonPort=None, port=None
-    ):
+    def setOverrides(self, overrideCountry=None, test_channel=None, jsonPort=None, port=None):
         """Override various items."""
         if overrideCountry:
             self._overrideCountry = overrideCountry
@@ -476,17 +481,14 @@ class SkyQRemote:
         url_index = 0
         self._soapControlURL = None
         while self._soapControlURL is None and url_index < 50:
-            self._soapControlURL = self._deviceAccess.getSoapControlURL(url_index)[
-                "url"
-            ]
+            self._soapControlURL = self._deviceAccess.getSoapControlURL(url_index)["url"]
             url_index += 1
 
         self.deviceSetup = True
 
     def _retrieveInformation(self, rest_path):
         try:
-            resp = self._deviceAccess.http_json(self._jsonport, rest_path)
-            return resp
+            return self._deviceAccess.http_json(self._jsonport, rest_path)
         except (
             requests.exceptions.ConnectTimeout,
             requests.exceptions.ConnectionError,
@@ -502,14 +504,10 @@ class SkyQRemote:
         """Work out the country for the Country Code."""
         try:
             country = pycountry.countries.get(alpha_3=countryCode).alpha_2.casefold()
-            SkyQCountry = importlib.import_module(
-                "pyskyqremote.country.remote_" + country
-            ).SkyQCountry
+            SkyQCountry = importlib.import_module("pyskyqremote.country.remote_" + country).SkyQCountry
 
         except (AttributeError, ModuleNotFoundError) as err:
-            _LOGGER.warning(
-                f"W0010 - Invalid country, defaulting to GBR: {self._host} : {countryCode} : {err}"
-            )
+            _LOGGER.warning(f"W0010 - Invalid country, defaulting to GBR: {self._host} : {countryCode} : {err}")
 
             from pyskyqremote.country.remote_gb import SkyQCountry
 
@@ -565,3 +563,13 @@ class SkyQRemote:
             channel,
             status,
         )
+
+    def _get_app_title(self, appId):
+        if len(self._apps) == 0:
+            apps = self._retrieveInformation(REST_PATH_APPS)
+            if not apps:
+                return None
+            for a in apps["apps"]:
+                self._apps[a["appId"]] = a["title"]
+
+        return self._apps[appId] if appId in self._apps else None
